==> ejc-sddjsorg-impl-3.0.0-20211019.091636-32-sources.jar: com/ejianc/business/production/bean/NoneCurrencyEntity.java <==
package com.ejianc.business.production.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 产权登记-非货币出资
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sddjsorg_production_none_currency")
public class NoneCurrencyEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="pid")
    private java.lang.Long pid; // 主表id(申请单id)
    @TableField(value="in_out_captail")
    private java.lang.String inOutCaptail; // 内/外部出资方
    @TableField(value="captail_name")
    private java.lang.String captailName; // 出资方名称
    @TableField(value="unified_social_credit_code")
    private java.lang.String unifiedSocialCreditCode; // 统一社会信用编码
    @TableField(value="captail_type")
    private java.lang.String captailType; // 出资人类别
    @TableField(value="subscribed_capital")
    private java.math.BigDecimal subscribedCapital; // 认缴资本
    @TableField(value="subscribed_capital_big")
    private java.lang.String subscribedCapitalBig; // 认缴资本(大写)
    @TableField(value="paid_capital")
    private java.math.BigDecimal paidCapital; // 实缴资本
    @TableField(value="paid_capital_big")
    private java.lang.String paidCapitalBig; // 实缴资本(大写)
    @TableField(value="equity_ratio")
    private java.math.BigDecimal equityRatio; // 股权比例
    @TableField(value="asset_appraisal_filing_no")
    private java.lang.String assetAppraisalFilingNo; // 产评估备案编号
    @TableField(value="assessment_value")
    private java.math.BigDecimal assessmentValue; // 评估值
    @TableField(value="assessment_value_big")
    private java.lang.String assessmentValueBig; // 评估值(大写)
    @TableField(value="has_record")
    private java.lang.Integer hasRecord; // 是否中电建备案
    @TableField(value="asset_item")
    private java.lang.String assetItem; // 资产项目
    
    
    

    /**
     * 主表id(申请单id)
     */
    public java.lang.Long getPid() {
        return pid;
    }

    /**
     * 主表id(申请单id)
     */
    public void setPid(java.lang.Long pid) {
        this.pid = pid;
    }
    /**
     * 内/外部出资方
     */
    public java.lang.String getInOutCaptail() {
        return inOutCaptail;
    }

    /**
     * 内/外部出资方
     */
    public void setInOutCaptail(java.lang.String inOutCaptail) {
        this.inOutCaptail = inOutCaptail;
    }
    /**
     * 出资方名称
     */
    public java.lang.String getCaptailName() {
        return captailName;
    }

    /**
     * 出资方名称
     */
    public void setCaptailName(java.lang.String captailName) {
        this.captailName = captailName;
    }
    /**
     * 统一社会信用编码
     */
    public java.lang.String getUnifiedSocialCreditCode() {
        return unifiedSocialCreditCode;
    }

    /**
     * 统一社会信用编码
     */
    public void setUnifiedSocialCreditCode(java.lang.String unifiedSocialCreditCode) {
        this.unifiedSocialCreditCode = unifiedSocialCreditCode;
    }
    /**
     * 出资人类别
     */
    public java.lang.String getCaptailType() {
        return captailType;
    }

    /**
     * 出资人类别
     */
    public void setCaptailType(java.lang.String captailType) {
        this.captailType = captailType;
    }
    /**
     * 认缴资本
     */
    public java.math.BigDecimal getSubscribedCapital() {
        return subscribedCapital;
    }

    /**
     * 认缴资本
     */
    public void setSubscribedCapital(java.math.BigDecimal subscribedCapital) {
        this.subscribedCapital = subscribedCapital;
    }
    /**
     * 认缴资本(大写)
     */
    public java.lang.String getSubscribedCapitalBig() {
        return subscribedCapitalBig;
    }

    /**
     * 认缴资本(大写)
     */
    public void setSubscribedCapitalBig(java.lang.String subscribedCapitalBig) {
        this.subscribedCapitalBig = subscribedCapitalBig;
    }
    /**
     * 实缴资本
     */
    public java.math.BigDecimal getPaidCapital() {
        return paidCapital;
    }

    /**
     * 实缴资本
     */
    public void setPaidCapital(java.math.BigDecimal paidCapital) {
        this.paidCapital = paidCapital;
    }
    /**
     * 实缴资本(大写)
     */
    public java.lang.String getPaidCapitalBig() {
        return paidCapitalBig;
    }

    /**
     * 实缴资本(大写)
     */
    public void setPaidCapitalBig(java.lang.String paidCapitalBig) {
        this.paidCapitalBig = paidCapitalBig;
    }
    /**
     * 股权比例
     */
    public java.math.BigDecimal getEquityRatio() {
        return equityRatio;
    }

    /**
     * 股权比例
     */
    public void setEquityRatio(java.math.BigDecimal equityRatio) {
        this.equityRatio = equityRatio;
    }
    /**
     * 产评估备案编号
     */
    public java.lang.String getAssetAppraisalFilingNo() {
        return assetAppraisalFilingNo;
    }

    /**
     * 产评估备案编号
     */
    public void setAssetAppraisalFilingNo(java.lang.String assetAppraisalFilingNo) {
        this.assetAppraisalFilingNo = assetAppraisalFilingNo;
    }
    /**
     * 评估值
     */
    public java.math.BigDecimal getAssessmentValue() {
        return assessmentValue;
    }

    /**
     * 评估值
     */
    public void setAssessmentValue(java.math.BigDecimal assessmentValue) {
        this.assessmentValue = assessmentValue;
    }
    /**
     * 评估值(大写)
     */
    public java.lang.String getAssessmentValueBig() {
        return assessmentValueBig;
    }

    /**
     * 评估值(大写)
     */
    public void setAssessmentValueBig(java.lang.String assessmentValueBig) {
        this.assessmentValueBig = assessmentValueBig;
    }
    /**
     * 是否中电建备案
     */
    public java.lang.Integer getHasRecord() {
        return hasRecord;
    }

    /**
     * 是否中电建备案
     */
    public void setHasRecord(java.lang.Integer hasRecord) {
        this.hasRecord = hasRecord;
    }
    /**
     * 资产项目
     */
    public java.lang.String getAssetItem() {
        return assetItem;
    }

    /**
     * 资产项目
     */
    public void setAssetItem(java.lang.String assetItem) {
        this.assetItem = assetItem;
    }
    
}

==> ejc-sddjsorg-impl-3.0.0-20211029.110352-117-sources.jar: com/ejianc/business/production/bean/NoneCurrencyEntity.java <==
package com.ejianc.business.production.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 产权登记-非货币出资
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sddjsorg_production_none_currency")
public class NoneCurrencyEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="pid")
    private java.lang.Long pid; // 主表id(申请单id)
    @TableField(value="in_out_captail")
    private java.lang.String inOutCaptail; // 内/外部出资方
    @TableField(value="captail_name")
    private java.lang.String captailName; // 出资方名称
    @TableField(value="unified_social_credit_code")
    private java.lang.String unifiedSocialCreditCode; // 统一社会信用编码
    @TableField(value="captail_type")
    private java.lang.String captailType; // 出资人类别
    @TableField(value="subscribed_capital")
    private java.math.BigDecimal subscribedCapital; // 认缴资本
    @TableField(value="subscribed_capital_big")
    private java.lang.String subscribedCapitalBig; // 认缴资本(大写)
    @TableField(value="paid_capital")
    private java.math.BigDecimal paidCapital; // 实缴资本
    @TableField(value="paid_capital_big")
    private java.lang.String paidCapitalBig; // 实缴资本(大写)
    @TableField(value="equity_ratio")
    private java.math.BigDecimal equityRatio; // 股权比例
    @TableField(value="asset_appraisal_filing_no")
    private java.lang.String assetAppraisalFilingNo; // 产评估备案编号
    @TableField(value="assessment_value")
    private java.math.BigDecimal assessmentValue; // 评估值
    @TableField(value="assessment_value_big")
    private java.lang.String assessmentValueBig; // 评估值(大写)
    @TableField(value="has_record")
    private java.lang.Integer hasRecord; // 是否中电建备案
    @TableField(value="asset_item")
    private java.lang.String assetItem; // 资产项目

    @TableField(value="whether_shareholder")
    private Boolean whetherShareholder;//是否新股东

    @TableField(value="contribution_type")
    private String contributionType; // 出资类别
    @TableField(value="captail_price")
    private BigDecimal captailPrice;//出资作价

    @TableField(value="captail_price_big")
    private String captailPriceBig;//出资作价大写
    @TableField(value="capital_increase_front_ratio")
    private BigDecimal capitalIncreaseFrontRatio;
    @TableField(value="assessment_object")
    private String assessmentObject;//评估对象

    /**
     * 主表id(申请单id)
     */
    public java.lang.Long getPid() {
        return pid;
    }

    /**
     * 主表id(申请单id)
     */
    public void setPid(java.lang.Long pid) {
        this.pid = pid;
    }
    /**
     * 内/外部出资方
     */
    public java.lang.String getInOutCaptail() {
        return inOutCaptail;
    }

    /**
     * 内/外部出资方
     */
    public void setInOutCaptail(java.lang.String inOutCaptail) {
        this.inOutCaptail = inOutCaptail;
    }
    /**
     * 出资方名称
     */
    public java.lang.String getCaptailName() {
        return captailName;
    }

    /**
     * 出资方名称
     */
    public void setCaptailName(java.lang.String captailName) {
        this.captailName = captailName;
    }
    /**
     * 统一社会信用编码
     */
    public java.lang.String getUnifiedSocialCreditCode() {
        return unifiedSocialCreditCode;
    }

    /**
     * 统一社会信用编码
     */
    public void setUnifiedSocialCreditCode(java.lang.String unifiedSocialCreditCode) {
        this.unifiedSocialCreditCode = unifiedSocialCreditCode;
    }
    /**
     * 出资人类别
     */
    public java.lang.String getCaptailType() {
        return captailType;
    }

    /**
     * 出资人类别
     */
    public void setCaptailType(java.lang.String captailType) {
        this.captailType = captailType;
    }
    /**
     * 认缴资本
     */
    public java.math.BigDecimal getSubscribedCapital() {
        return subscribedCapital;
    }

    /**
     * 认缴资本
     */
    public void setSubscribedCapital(java.math.BigDecimal subscribedCapital) {
        this.subscribedCapital = subscribedCapital;
    }
    /**
     * 认缴资本(大写)
     */
    public java.lang.String getSubscribedCapitalBig() {
        return subscribedCapitalBig;
    }

    /**
     * 认缴资本(大写)
     */
    public void setSubscribedCapitalBig(java.lang.String subscribedCapitalBig) {
        this.subscribedCapitalBig = subscribedCapitalBig;
    }
    /**
     * 实缴资本
     */
    public java.math.BigDecimal getPaidCapital() {
        return paidCapital;
    }

    /**
     * 实缴资本
     */
    public void setPaidCapital(java.math.BigDecimal paidCapital) {
        this.paidCapital = paidCapital;
    }
    /**
     * 实缴资本(大写)
     */
    public java.lang.String getPaidCapitalBig() {
        return paidCapitalBig;
    }

    /**
     * 实缴资本(大写)
     */
    public void setPaidCapitalBig(java.lang.String paidCapitalBig) {
        this.paidCapitalBig = paidCapitalBig;
    }
    /**
     * 股权比例
     */
    public java.math.BigDecimal getEquityRatio() {
        return equityRatio;
    }

    /**
     * 股权比例
     */
    public void setEquityRatio(java.math.BigDecimal equityRatio) {
        this.equityRatio = equityRatio;
    }
    /**
     * 产评估备案编号
     */
    public java.lang.String getAssetAppraisalFilingNo() {
        return assetAppraisalFilingNo;
    }

    /**
     * 产评估备案编号
     */
    public void setAssetAppraisalFilingNo(java.lang.String assetAppraisalFilingNo) {
        this.assetAppraisalFilingNo = assetAppraisalFilingNo;
    }
    /**
     * 评估值
     */
    public java.math.BigDecimal getAssessmentValue() {
        return assessmentValue;
    }

    /**
     * 评估值
     */
    public void setAssessmentValue(java.math.BigDecimal assessmentValue) {
        this.assessmentValue = assessmentValue;
    }
    /**
     * 评估值(大写)
     */
    public java.lang.String getAssessmentValueBig() {
        return assessmentValueBig;
    }

    /**
     * 评估值(大写)
     */
    public void setAssessmentValueBig(java.lang.String assessmentValueBig) {
        this.assessmentValueBig = assessmentValueBig;
    }
    /**
     * 是否中电建备案
     */
    public java.lang.Integer getHasRecord() {
        return hasRecord;
    }

    /**
     * 是否中电建备案
     */
    public void setHasRecord(java.lang.Integer hasRecord) {
        this.hasRecord = hasRecord;
    }
    /**
     * 资产项目
     */
    public java.lang.String getAssetItem() {
        return assetItem;
    }

    /**
     * 资产项目
     */
    public void setAssetItem(java.lang.String assetItem) {
        this.assetItem = assetItem;
    }

    public Boolean getWhetherShareholder() {
        return whetherShareholder;
    }

    public void setWhetherShareholder(Boolean whetherShareholder) {
        this.whetherShareholder = whetherShareholder;
    }

    public String getContributionType() {
        return contributionType;
    }

    public void setContributionType(String contributionType) {
        this.contributionType = contributionType;
    }

    public BigDecimal getCaptailPrice() {
        return captailPrice;
    }

    public void setCaptailPrice(BigDecimal captailPrice) {
        this.captailPrice = captailPrice;
    }

    public String getCaptailPriceBig() {
        return captailPriceBig;
    }

    public void setCaptailPriceBig(String captailPriceBig) {
        this.captailPriceBig = captailPriceBig;
    }

    public BigDecimal getCapitalIncreaseFrontRatio() {
        return capitalIncreaseFrontRatio;
    }

    public void setCapitalIncreaseFrontRatio(BigDecimal capitalIncreaseFrontRatio) {
        this.capitalIncreaseFrontRatio = capitalIncreaseFrontRatio;
    }

    public String getAssessmentObject() {
        return assessmentObject;
    }

    public void setAssessmentObject(String assessmentObject) {
        this.assessmentObject = assessmentObject;
    }
}
